Function gut_lib::display::write_column[][src]

pub fn write_column(first: String, second: String, offset: Option<usize>)

Displays a two column text in the terminal

The function will use the provided Strings and output them in two columns.

This function will panic if it fails to write to the terminal.